@@ -37,10 +37,10 @@ from trove.common import context as rd_context
 from trove.common import exception
 from trove.common.i18n import _
 from trove.common import pastedeploy
+from trove.common import policy
 from trove.common import utils
 
 CONTEXT_KEY = 'trove.context'
-Router = base_wsgi.Router
 Debug = base_wsgi.Debug
 Middleware = base_wsgi.Middleware
 JSONDictSerializer = base_wsgi.JSONDictSerializer
@@ -80,7 +80,7 @@ def launch(app_name, port, paste_config_file, data={},
     app = pastedeploy.paste_deploy_app(paste_config_file, app_name, data)
     server = base_wsgi.Service(app, port, host=host,
                                backlog=backlog, threads=threads)
-    return service.launch(CONF, server, workers)
+    return service.launch(CONF, server, workers, restart_method='mutate')
 
 
 # Note: taken from Nova
@@ -324,6 +324,7 @@ class Controller(object):
             exception.ModuleAppliedToInstance,
             exception.PolicyNotAuthorized,
             exception.LogAccessForbidden,
+            exception.TroveOperationAuthError,
         ],
         webob.exc.HTTPBadRequest: [
             exception.InvalidModelError,
@@ -368,7 +369,8 @@ class Controller(object):
             exception.LocalStorageNotSupported,
             exception.DatastoreOperationNotSupported,
             exception.ClusterInstanceOperationNotSupported,
-            exception.ClusterDatastoreNotSupported
+            exception.ClusterDatastoreNotSupported,
+            exception.LogsNotAvailable
         ],
     }
 
@@ -509,7 +511,7 @@ class Fault(webob.exc.HTTPException):
 
         content_type = req.best_match_content_type()
         serializer = {
-            'application/json': base_wsgi.JSONDictSerializer(),
+            'application/json': JSONDictSerializer(),
         }[content_type]
 
         self.wrapped_exc.body = serializer.serialize(fault_data, content_type)
@@ -540,19 +542,22 @@ class ContextMiddleware(base_wsgi.Middleware):
         user_id = request.headers.get('X-User-ID', None)
         roles = request.headers.get('X-Role', '').split(',')
         is_admin = False
-        for role in roles:
-            if role.lower() in self.admin_roles:
-                is_admin = True
-                break
         limits = self._extract_limits(request.params)
         context = rd_context.TroveContext(auth_token=auth_token,
-                                          tenant=tenant_id,
-                                          user=user_id,
+                                          project_id=tenant_id,
+                                          user_id=user_id,
                                           is_admin=is_admin,
                                           limit=limits.get('limit'),
                                           marker=limits.get('marker'),
                                           service_catalog=service_catalog,
                                           roles=roles)
+        if self.admin_roles:
+            for role in roles:
+                if role.lower() in self.admin_roles:
+                    context.is_admin = True
+                    break
+        else:
+            context.is_admin = policy.check_is_admin(context)
         request.environ[CONTEXT_KEY] = context
 
     @classmethod
@@ -657,10 +662,3 @@ class DictSerializer(ActionDispatcher):
 
     def default(self, data):
         return ""
-
-
-class JSONDictSerializer(DictSerializer):
-    """Default JSON request body serialization."""
-
-    def default(self, data):
-        return jsonutils.dump_as_bytes(data)
