@@ -12,20 +12,22 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 from collections import OrderedDict
+import os
 
 from oslo_log import log as logging
 import psycopg2
 
 from trove.common import cfg
+from trove.common import constants
+from trove.common.db.postgresql import models
 from trove.common import exception
 from trove.common import stream_codecs
 from trove.common import utils
-from trove.common.db.postgresql import models
 from trove.guestagent.common import configuration
 from trove.guestagent.common import guestagent_utils
 from trove.guestagent.common import operating_system
-from trove.guestagent.datastore import service
 from trove.guestagent.datastore.postgres import query
+from trove.guestagent.datastore import service
 from trove.guestagent.utils import docker as docker_util
 from trove.instance import service_status
 
@@ -83,8 +85,8 @@ class PgSqlApp(service.BaseDbApp):
 
         self._configuration_manager = configuration.ConfigurationManager(
             CONFIG_FILE,
-            CONF.database_service_uid,
-            CONF.database_service_uid,
+            self.database_service_uid,
+            self.database_service_gid,
             stream_codecs.KeyValueCodec(
                 value_quoting=True,
                 bool_case=stream_codecs.KeyValueCodec.BOOL_LOWER,
@@ -141,8 +143,8 @@ class PgSqlApp(service.BaseDbApp):
             stream_codecs.PropertiesCodec(string_mappings={'\t': None}),
             as_root=True)
         operating_system.chown(HBA_CONFIG_FILE,
-                               CONF.database_service_uid,
-                               CONF.database_service_uid,
+                               self.database_service_uid,
+                               self.database_service_gid,
                                as_root=True)
         operating_system.chmod(HBA_CONFIG_FILE,
                                operating_system.FileMode.SET_USR_RO,
@@ -172,19 +174,20 @@ class PgSqlApp(service.BaseDbApp):
             postgres_pass = utils.generate_random_password()
 
         # Get uid and gid
-        user = "%s:%s" % (CONF.database_service_uid, CONF.database_service_uid)
+        user = "%s:%s" % (self.database_service_uid, self.database_service_gid)
 
         # Create folders for postgres on localhost
-        for folder in ['/etc/postgresql', '/var/run/postgresql']:
+        for folder in ['/etc/postgresql',
+                       constants.POSTGRESQL_HOST_SOCKET_PATH]:
             operating_system.ensure_directory(
-                folder, user=CONF.database_service_uid,
-                group=CONF.database_service_uid, force=True,
+                folder, user=self.database_service_uid,
+                group=self.database_service_gid, force=True,
                 as_root=True)
 
         volumes = {
             "/etc/postgresql": {"bind": "/etc/postgresql", "mode": "rw"},
-            "/var/run/postgresql": {"bind": "/var/run/postgresql",
-                                    "mode": "rw"},
+            constants.POSTGRESQL_HOST_SOCKET_PATH:
+                {"bind": "/var/run/postgresql", "mode": "rw"},
             "/var/lib/postgresql": {"bind": "/var/lib/postgresql",
                                     "mode": "rw"},
             "/var/lib/postgresql/data": {"bind": "/var/lib/postgresql/data",
@@ -200,12 +203,18 @@ class PgSqlApp(service.BaseDbApp):
             for port in port_range:
                 ports[f'{port}/tcp'] = port
 
+        if CONF.network_isolation and \
+                os.path.exists(constants.ETH1_CONFIG_PATH):
+            network_mode = constants.DOCKER_HOST_NIC_MODE
+        else:
+            network_mode = constants.DOCKER_BRIDGE_MODE
+
         try:
             docker_util.start_container(
                 self.docker_client,
                 image,
                 volumes=volumes,
-                network_mode="bridge",
+                network_mode=network_mode,
                 ports=ports,
                 user=user,
                 environment={
@@ -232,10 +241,11 @@ class PgSqlApp(service.BaseDbApp):
         LOG.info("Restarting database")
 
         # Ensure folders permission for database.
-        for folder in ['/etc/postgresql', '/var/run/postgresql']:
+        for folder in ['/etc/postgresql',
+                       constants.POSTGRESQL_HOST_SOCKET_PATH]:
             operating_system.ensure_directory(
-                folder, user=CONF.database_service_uid,
-                group=CONF.database_service_uid, force=True,
+                folder, user=self.database_service_uid,
+                group=self.database_service_gid, force=True,
                 as_root=True)
 
         try:
@@ -255,8 +265,8 @@ class PgSqlApp(service.BaseDbApp):
     def restore_backup(self, context, backup_info, restore_location):
         backup_id = backup_info['id']
         storage_driver = CONF.storage_strategy
-        backup_driver = cfg.get_configuration_property('backup_strategy')
-        image = cfg.get_configuration_property('backup_docker_image')
+        backup_driver = self.get_backup_strategy()
+        image = self.get_backup_image()
         name = 'db_restore'
         volumes = {
             '/var/lib/postgresql/data': {
@@ -301,8 +311,8 @@ class PgSqlApp(service.BaseDbApp):
             raise Exception(msg)
 
         for dir in [WAL_ARCHIVE_DIR, self.datadir]:
-            operating_system.chown(dir, CONF.database_service_uid,
-                                   CONF.database_service_uid, force=True,
+            operating_system.chown(dir, self.database_service_uid,
+                                   self.database_service_gid, force=True,
                                    as_root=True)
 
     def is_replica(self):
@@ -331,10 +341,10 @@ class PgSqlApp(service.BaseDbApp):
     def pg_rewind(self, conn_info):
         docker_image = CONF.get(CONF.datastore_manager).docker_image
         image = f'{docker_image}:{CONF.datastore_version}'
-        user = "%s:%s" % (CONF.database_service_uid, CONF.database_service_uid)
+        user = "%s:%s" % (self.database_service_uid, self.database_service_gid)
         volumes = {
-            "/var/run/postgresql": {"bind": "/var/run/postgresql",
-                                    "mode": "rw"},
+            constants.POSTGRESQL_HOST_SOCKET_PATH:
+                {"bind": "/var/run/postgresql", "mode": "rw"},
             "/var/lib/postgresql": {"bind": "/var/lib/postgresql",
                                     "mode": "rw"},
             "/var/lib/postgresql/data": {"bind": "/var/lib/postgresql/data",
@@ -738,7 +748,8 @@ class PgSqlAdmin(object):
 
 
 class PostgresConnection(object):
-    def __init__(self, user, password=None, host='/var/run/postgresql',
+    def __init__(self, user, password=None,
+                 host=constants.POSTGRESQL_HOST_SOCKET_PATH,
                  port=5432):
         """Utility class to communicate with PostgreSQL.
 
