@@ -23,8 +23,8 @@ from trove.backup.state import BackupState
 from trove.common import cfg
 from trove.common import context as trove_context
 from trove.common import exception
-from trove.common import stream_codecs
 from trove.common.i18n import _
+from trove.common import stream_codecs
 from trove.conductor import api as conductor_api
 from trove.guestagent.common import guestagent_utils
 from trove.guestagent.common import operating_system
@@ -290,15 +290,15 @@ class BaseDbStatus(object):
         # outside.
         loop = True
 
-        # We need 3 (by default) consecutive success db connections for status
+        # We need 5 (by default) consecutive success db connections for status
         # 'HEALTHY'
         healthy_count = 0
-
+        state_healthy_counts = CONF.state_healthy_counts - 1
         while loop:
             self.status = self.get_actual_db_status()
             if self.status == status:
                 if (status == service_status.ServiceStatuses.HEALTHY and
-                        healthy_count < 2):
+                        healthy_count < state_healthy_counts):
                     healthy_count += 1
                     time.sleep(CONF.state_change_poll_time)
                     continue
@@ -310,7 +310,8 @@ class BaseDbStatus(object):
             # should we remain in this loop? this is the thing
             # that emulates the do-while construct.
             loop = (time.time() < end_time)
-
+            # reset the healthy_count
+            healthy_count = 0
             # no point waiting if our time is up and we're
             # just going to error out anyway.
             if loop:
@@ -414,8 +415,32 @@ class BaseDbApp(object):
         self.reset_configuration(config_contents)
         self.start_db(update_db=True, ds_version=ds_version)
 
+    @staticmethod
+    def _image_has_tag(image):
+        """
+        Whether docker_image being config with tag
+            "example.domain:5000/repo/image_name:tag",
+            "example.domain:5000/repo/image-name:tag",
+            "example.domain:5000/repo/image-name:tag_tag",
+            "example.domain:5000/repo/image_name:tag-tag",
+            "example.domain:5000/repo/image-name",
+            "example.domain:5000/repo/image_name",
+            "example.domain:5000:5000/repo/image-name",
+            "example.domain/repo/image-name",
+            "example.domain/repo/image-name:tag"
+
+        Returns:
+            - True if match
+        """
+        return image.split('/')[-1].find(':') > 0
+
     def get_backup_image(self):
-        return cfg.get_configuration_property('backup_docker_image')
+        image = cfg.get_configuration_property('backup_docker_image')
+        if not self._image_has_tag(image):
+            ds_version = CONF.datastore_version
+            image = (f'{image}:latest' if not ds_version else
+                     f'{image}:{ds_version}')
+        return image
 
     def get_backup_strategy(self):
         return cfg.get_configuration_property('backup_strategy')
@@ -537,3 +562,13 @@ class BaseDbApp(object):
                 sent=timeutils.utcnow_ts(microsecond=True),
                 **backup_state)
             LOG.debug("Updated state for %s to %s.", backup_id, backup_state)
+
+    @property
+    def database_service_uid(self):
+        return cfg.get_configuration_property(
+            'database_service_uid') or CONF.database_service_uid
+
+    @property
+    def database_service_gid(self):
+        return cfg.get_configuration_property(
+            'database_service_gid') or self.database_service_uid
