@@ -33,20 +33,21 @@ from sqlalchemy import func
 from trove.backup.models import Backup
 from trove.common import cfg
 from trove.common import clients
+from trove.common import constants
 from trove.common import crypto_utils as cu
 from trove.common import exception
+from trove.common.i18n import _
 from trove.common import neutron
 from trove.common import notification
 from trove.common import server_group as srv_grp
 from trove.common import template
 from trove.common import timeutils
-from trove.common import utils
-from trove.common.i18n import _
 from trove.common.trove_remote import create_trove_client
+from trove.common import utils
 from trove.configuration.models import Configuration
 from trove.datastore import models as datastore_models
-from trove.datastore.models import DBDatastoreVersionMetadata
 from trove.datastore.models import DatastoreVersionMetadata as dvm
+from trove.datastore.models import DBDatastoreVersionMetadata
 from trove.db import get_db_api
 from trove.db import models as dbmodels
 from trove.extensions.security_group.models import SecurityGroup
@@ -141,14 +142,14 @@ def load_simple_instance_server_status(context, db_info):
 
 def load_simple_instance_addresses(context, db_info):
     """Get addresses of the instance from Neutron."""
-    if 'BUILDING' == db_info.task_status.action and not db_info.cluster_id:
-        db_info.addresses = []
-        return
-
     addresses = []
     user_ports = []
-    client = clients.create_neutron_client(context, db_info.region_id)
-    ports = neutron.get_instance_ports(client, db_info.compute_instance_id)
+    try:
+        client = clients.create_neutron_client(context, db_info.region_id)
+        ports = neutron.get_instance_ports(client, db_info.compute_instance_id)
+    except nova_exceptions.NotFound:
+        db_info.addresses = []
+        return
     for port in ports:
         if port['network_id'] not in CONF.management_networks:
             LOG.debug('Found user port %s for instance %s', port['id'],
@@ -249,7 +250,7 @@ class SimpleInstance(object):
         ips = self.get_visible_ip_addresses()
         if ips:
             # FIXME
-            return ips[0]
+            return ips[0]['address']
 
     @property
     def flavor_id(self):
@@ -504,7 +505,7 @@ class SimpleInstance(object):
     @property
     def access(self):
         if hasattr(self.db_info, 'access'):
-            if type(self.db_info.access) == str:
+            if isinstance(self.db_info.access, str):
                 return json.loads(self.db_info.access)
             return self.db_info.access
         else:
@@ -992,7 +993,32 @@ class BaseInstance(SimpleInstance):
 
         return userdata if userdata else ""
 
-    def get_injected_files(self, datastore_manager, datastore_version):
+    @property
+    def datastore_registry_ext(self):
+        registry_ext = constants.REGISTRY_EXT_DEFAULTS.get(
+            self.ds_version.manager)
+        if self.ds_version.registry_ext:
+            registry_ext = self.ds_version.registry_ext
+
+        return "%(manager)s:%(registry_ext)s" % {
+            "manager": self.ds_version.manager,
+            "registry_ext": registry_ext
+        }
+
+    @property
+    def datastore_repl_strategy(self):
+        if self.ds_version.repl_strategy:
+            return self.ds_version.repl_strategy
+
+        return "%s.%s" % (
+            CONF.get(self.ds_version.manager).replication_namespace,
+            CONF.get(self.ds_version.manager).replication_strategy
+        )
+
+    def get_injected_files(self,
+                           datastore_manager,
+                           datastore_version,
+                           **kwargs):
         injected_config_location = CONF.get('injected_config_location')
         guest_info = CONF.get('guest_info')
 
@@ -1011,11 +1037,20 @@ class BaseInstance(SimpleInstance):
                 "datastore_manager=%s\n"
                 "datastore_version=%s\n"
                 "tenant_id=%s\n"
+                "datastore_registry_ext=%s\n"
+                "replication_strategy=%s\n"
                 % (self.id, datastore_manager, datastore_version,
-                   self.tenant_id)
+                   self.tenant_id, self.datastore_registry_ext,
+                   self.datastore_repl_strategy)
             )
         }
 
+        # pass through the network_isolation to guest
+        files = {
+            guest_info_file: ("%snetwork_isolation=%s\n" %
+                              (files.get(guest_info_file),
+                               CONF.network.network_isolation))
+        }
         instance_key = get_instance_encryption_key(self.id)
         if instance_key:
             files = {
@@ -1040,10 +1075,18 @@ class BaseInstance(SimpleInstance):
         # Configure docker's daemon.json if the directives exist in trove.conf
         docker_daemon_values = {}
 
-        # Configure docker_bridge_network_ip in order to change the docker
-        # default range(172.17.0.0/16) of bridge network
-        if CONF.docker_bridge_network_ip:
-            docker_daemon_values["bip"] = CONF.docker_bridge_network_ip
+        # In case that user enables network_isolation with management/bussiness
+        # network not set
+        if CONF.network.network_isolation and \
+                kwargs.get("disable_bridge", False):
+            docker_daemon_values["bridge"] = "none"
+            docker_daemon_values["ip-forward"] = False
+            docker_daemon_values["iptables"] = False
+        else:
+            # Configure docker_bridge_network_ip in order to change the docker
+            # default range(172.17.0.0/16) of bridge network
+            if CONF.docker_bridge_network_ip:
+                docker_daemon_values["bip"] = CONF.docker_bridge_network_ip
         if CONF.docker_insecure_registries:
             docker_daemon_values["insecure-registries"] = \
                 CONF.docker_insecure_registries
@@ -2052,22 +2095,23 @@ def module_instance_count(context, module_id, include_clustered=False):
                func.max(module_models.DBInstanceModule.updated)]
     filters = [module_models.DBInstanceModule.module_id == module_id,
                module_models.DBInstanceModule.deleted == 0]
-    query = module_models.DBInstanceModule.query()
-    query = query.join(
-        module_models.DBModule,
-        module_models.DBInstanceModule.module_id == module_models.DBModule.id)
-    query = query.join(
-        DBInstance,
-        module_models.DBInstanceModule.instance_id == DBInstance.id)
-    if not include_clustered:
-        filters.append(DBInstance.cluster_id.is_(None))
-    if not context.is_admin:
-        filters.append(DBInstance.tenant_id == context.project_id)
-    query = query.group_by(module_models.DBInstanceModule.md5)
-    query = query.add_columns(*columns)
-    query = query.filter(*filters)
-    query = query.order_by(module_models.DBInstanceModule.updated)
-    return query.all()
+    with module_models.DBInstanceModule.query() as query:
+        query = query.join(
+            module_models.DBModule,
+            module_models.DBInstanceModule.module_id ==
+            module_models.DBModule.id)
+        query = query.join(
+            DBInstance,
+            module_models.DBInstanceModule.instance_id == DBInstance.id)
+        if not include_clustered:
+            filters.append(DBInstance.cluster_id.is_(None))
+        if not context.is_admin:
+            filters.append(DBInstance.tenant_id == context.project_id)
+        query = query.group_by(module_models.DBInstanceModule.md5)
+        query = query.add_columns(*columns)
+        query = query.filter(*filters)
+        query = query.order_by(module_models.DBInstanceModule.updated)
+        return query.all()
 
 
 def persist_instance_fault(notification, event_qualifier):
