@@ -13,6 +13,7 @@
 #    under the License.
 
 import copy
+import json
 import time
 import traceback
 
@@ -21,24 +22,20 @@ from eventlet.timeout import Timeout
 from oslo_log import log as logging
 from swiftclient.client import ClientException
 
-from trove import rpc
 from trove.backup import models as bkup_models
 from trove.backup.models import Backup
 from trove.backup.models import DBBackup
 from trove.backup.state import BackupState
-from trove.cluster import tasks
 from trove.cluster.models import Cluster
 from trove.cluster.models import DBCluster
+from trove.cluster import tasks
 from trove.common import cfg
 from trove.common import clients
-from trove.common import exception
-from trove.common import neutron
-from trove.common import template
-from trove.common import timeutils
-from trove.common import utils
 from trove.common.clients import create_cinder_client
 from trove.common.clients import create_dns_client
 from trove.common.clients import create_guest_client
+from trove.common import constants
+from trove.common import exception
 from trove.common.exception import BackupCreationError
 from trove.common.exception import GuestError
 from trove.common.exception import GuestTimeout
@@ -47,6 +44,7 @@ from trove.common.exception import PollTimeOut
 from trove.common.exception import TroveError
 from trove.common.exception import VolumeCreationFailure
 from trove.common.i18n import _
+from trove.common import neutron
 from trove.common.notification import DBaaSInstanceRestart
 from trove.common.notification import DBaaSInstanceUpgrade
 from trove.common.notification import EndNotification
@@ -54,20 +52,25 @@ from trove.common.notification import StartNotification
 from trove.common.notification import TroveInstanceCreate
 from trove.common.notification import TroveInstanceModifyFlavor
 from trove.common.strategies.cluster import strategy
+from trove.common import template
+from trove.common import timeutils
+from trove.common import utils
 from trove.common.utils import try_recover
 from trove.configuration import models as config_models
 from trove.extensions.mysql import models as mysql_models
 from trove.instance import models as inst_models
-from trove.instance import service_status as srvstatus
 from trove.instance.models import DBInstance
 from trove.instance.models import FreshInstance
 from trove.instance.models import Instance
 from trove.instance.models import InstanceServiceStatus
 from trove.instance.models import InstanceStatus
+from trove.instance.models import load_simple_instance_addresses
+from trove.instance import service_status as srvstatus
 from trove.instance.tasks import InstanceTasks
 from trove.module import models as module_models
 from trove.module import views as module_views
 from trove.quota.quota import run_with_quotas
+from trove import rpc
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -116,7 +119,7 @@ class NotifyMixin(object):
             'state_description': self.status,
             'state': self.status,
             'tenant_id': self.tenant_id,
-            'user_id': self.context.user,
+            'user_id': self.context.user_id,
         }
 
         if CONF.get(self.datastore_version.manager).volume_support:
@@ -228,6 +231,17 @@ class ClusterTasks(Cluster):
             ]
         )
 
+    def _all_instances_healthy(self, instance_ids, cluster_id, shard_id=None):
+        """Wait for all instances to become HEALTHY."""
+        return self._all_instances_acquire_status(
+            instance_ids, cluster_id, shard_id,
+            srvstatus.ServiceStatuses.HEALTHY,
+            fast_fail_statuses=[
+                srvstatus.ServiceStatuses.FAILED,
+                srvstatus.ServiceStatuses.FAILED_TIMEOUT_GUESTAGENT
+            ]
+        )
+
     def _all_instances_acquire_status(
             self, instance_ids, cluster_id, shard_id, expected_status,
             fast_fail_statuses=None):
@@ -557,6 +571,31 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         )
         return networks
 
+    def _get_user_nic_info(self, port_id):
+        nic_info = dict()
+        port = self.neutron_client.show_port(port_id)
+        fixed_ips = port['port']["fixed_ips"]
+        nic_info["mac_address"] = port['port']["mac_address"]
+        for fixed_ip in fixed_ips:
+            subnet = self.neutron_client.show_subnet(
+                fixed_ip["subnet_id"])['subnet']
+            if subnet.get("ip_version") == 4:
+                nic_info["ipv4_address"] = fixed_ip.get("ip_address")
+                nic_info["ipv4_cidr"] = subnet.get("cidr")
+                nic_info["ipv4_gateway"] = subnet.get("gateway_ip")
+                nic_info["ipv4_host_routes"] = subnet.get("host_routes")
+            # NOTE: only if the ipv6_ra_mode is dhcpv6-stateful,
+            # we need to configure the ip route for container. for slaac
+            # and dhcpv6-stateless mode, the route will be configured
+            # by the nic itself via the RA protocol.
+            elif subnet.get("ip_version") == 6:
+                nic_info["ipv6_address"] = fixed_ip.get("ip_address")
+                nic_info["ipv6_cidr"] = subnet.get("cidr")
+                nic_info["ipv6_host_routes"] = subnet.get("host_routes")
+                if subnet.get("ipv6_ra_mode") == "dhcpv6-stateful":
+                    nic_info["ipv6_gateway"] = subnet.get("gateway_ip")
+        return nic_info
+
     def create_instance(self, flavor, image_id, databases, users,
                         datastore_manager, packages, volume_size,
                         backup_id, availability_zone, root_password, nics,
@@ -573,11 +612,21 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             "Creating instance %s, nics: %s, access: %s",
             self.id, nics, access
         )
-
         networks = self._prepare_networks_for_instance(
             datastore_manager, nics, access=access
         )
-        files = self.get_injected_files(datastore_manager, ds_version)
+
+        if CONF.network.network_isolation and len(nics) > 1:
+            # the user defined port is always the first one.
+            nic_info = self._get_user_nic_info(networks[0]["port-id"])
+            LOG.debug("Generate the eth1_config.json file: %s", nic_info)
+            files = self.get_injected_files(datastore_manager,
+                                            ds_version,
+                                            disable_bridge=True)
+            files[constants.ETH1_CONFIG_PATH] = json.dumps(nic_info)
+        else:
+            files = self.get_injected_files(datastore_manager, ds_version)
+
         cinder_volume_type = volume_type or CONF.cinder_volume_type
         volume_info = self._create_server_volume(
             flavor['id'], image_id,
@@ -832,7 +881,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
     def _create_server_volume(self, flavor_id, image_id, datastore_manager,
                               volume_size, availability_zone, nics, files,
                               volume_type, scheduler_hints):
-        LOG.debug("Begin _create_server_volume for id: %s", self.id)
+        LOG.debug("Begin _create_server_volume for instance: %s", self.id)
         server = None
         volume_info = self._build_volume_info(
             datastore_manager,
@@ -840,6 +889,17 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             volume_type=volume_type,
             availability_zone=availability_zone)
         block_device_mapping_v2 = volume_info['block_device']
+
+        if CONF.volume_rootdisk_support:
+            block_device_mapping_v2.insert(
+                0, self._create_root_volume(
+                    image_id,
+                    CONF.volume_rootdisk_size,
+                    volume_type,
+                    availability_zone
+                ))
+            image_id = None
+
         try:
             server = self._create_server(
                 flavor_id, image_id,
@@ -856,7 +916,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             exc_fmt = _("Failed to create server for instance %s")
             err = inst_models.InstanceTasks.BUILDING_ERROR_SERVER
             self._log_and_raise(e, log_fmt, exc_fmt, self.id, err)
-        LOG.debug("End _create_server_volume for id: %s", self.id)
+        LOG.debug("End _create_server_volume for instance: %s", self.id)
         return volume_info
 
     def _build_volume_info(self, datastore_manager, volume_size=None,
@@ -905,6 +965,44 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         full_message = "%s%s" % (exc_fmt % fmt_content, exc_message)
         raise TroveError(message=full_message)
 
+    def _create_root_volume(self, image_id,
+                            volume_size, volume_type, availability_zone):
+        LOG.debug("Begin _create_root_volume for instance: %s", self.id)
+        volume_client = create_cinder_client(self.context, self.region_name)
+        volume_desc = ("root volume for %s" % self.id)
+        volume_kwargs = {
+            'size': volume_size,
+            'name': "trove-%s" % self.id,
+            'description': volume_desc,
+            'volume_type': volume_type,
+            'imageRef': image_id
+        }
+        if CONF.enable_volume_az:
+            volume_kwargs['availability_zone'] = availability_zone
+
+        volume_ref = volume_client.volumes.create(**volume_kwargs)
+
+        utils.poll_until(
+            lambda: volume_client.volumes.get(volume_ref.id),
+            lambda v_ref: v_ref.status in ['available', 'error'],
+            sleep_time=2,
+            time_out=CONF.volume_time_out)
+
+        v_ref = volume_client.volumes.get(volume_ref.id)
+        if v_ref.status in ['error']:
+            raise VolumeCreationFailure()
+
+        block_device_mapping_v2 = {
+            "uuid": v_ref.id,
+            "boot_index": 0,
+            "source_type": "volume",
+            "destination_type": "volume",
+            "delete_on_termination": True
+        }
+
+        LOG.debug("End _create_root_volume for instance: %s", self.id)
+        return block_device_mapping_v2
+
     def _create_volume(self, volume_size, volume_type, datastore_manager,
                        availability_zone):
         LOG.debug("Begin _create_volume for id: %s", self.id)
@@ -980,7 +1078,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                        nics, files={}, scheduler_hints=None):
         userdata = self.prepare_userdata(datastore_manager)
         metadata = {'trove_project_id': self.tenant_id,
-                    'trove_user_id': self.context.user,
+                    'trove_user_id': self.context.user_id,
                     'trove_instance_id': self.id}
         bdmap_v2 = block_device_mapping_v2
         config_drive = CONF.use_nova_server_config_drive
@@ -1057,9 +1155,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
 
             utils.poll_until(get_server, ip_is_available,
                              sleep_time=1, time_out=CONF.dns_time_out)
-            server = self.nova_client.servers.get(
-                self.db_info.compute_instance_id)
-            self.db_info.addresses = server.addresses
+            load_simple_instance_addresses(self.context, self.db_info)
             LOG.debug("Creating dns entry...")
             ip = self.dns_ip_address
             if not ip:
