@@ -16,6 +16,7 @@ import datetime
 from unittest.mock import DEFAULT
 from unittest.mock import MagicMock
 from unittest.mock import patch
+
 from swiftclient.client import ClientException
 
 from trove.backup import models
@@ -207,9 +208,9 @@ class BackupCreateTest(trove_testtools.TestCase):
         instance = MagicMock()
         instance.cluster_id = 'bad_id'
         with patch.object(instance_models.BuiltInstance, 'load',
-                          return_value=instance),\
+                          return_value=instance), \
             patch.object(models.Backup, 'validate_can_perform_action',
-                         return_value=None),\
+                         return_value=None), \
             patch.object(models.Backup, 'verify_swift_auth_token',
                          return_value=None):
             self.assertRaises(exception.ClusterInstanceOperationNotSupported,
@@ -222,13 +223,13 @@ class BackupCreateTest(trove_testtools.TestCase):
         instance = MagicMock()
         instance.cluster_id = None
         with patch.object(instance_models.BuiltInstance, 'load',
-                          return_value=instance),\
+                          return_value=instance), \
             patch.object(models.Backup, 'validate_can_perform_action',
-                         return_value=None),\
+                         return_value=None), \
             patch.object(models.Backup, 'verify_swift_auth_token',
-                         return_value=None),\
+                         return_value=None), \
             patch.object(DatabaseModelBase, 'is_valid',
-                         return_value=False),\
+                         return_value=False), \
             patch('trove.quota.quota.QuotaEngine.reserve',
                   return_value=[]):
             DatabaseModelBase.errors = {}
@@ -467,8 +468,8 @@ class PaginationTests(trove_testtools.TestCase):
 
     def tearDown(self):
         super(PaginationTests, self).tearDown()
-        query = models.DBBackup.query()
-        query.filter_by(instance_id=self.instance_id).delete()
+        with models.DBBackup.query() as query:
+            query.filter_by(instance_id=self.instance_id).delete()
 
     def test_pagination_list(self):
         # page one
@@ -540,8 +541,8 @@ class OrderingTests(trove_testtools.TestCase):
 
     def tearDown(self):
         super(OrderingTests, self).tearDown()
-        query = models.DBBackup.query()
-        query.filter_by(instance_id=self.instance_id).delete()
+        with models.DBBackup.query() as query:
+            query.filter_by(instance_id=self.instance_id).delete()
 
     def test_list(self):
         backups, marker = models.Backup.list(self.context)
